@@ -396,6 +396,9 @@ class Mat : public Base< eT, Mat<eT> >
   inline arma_warn_unused bool is_sorted(const char* direction = "ascend")       const;
   inline arma_warn_unused bool is_sorted(const char* direction, const uword dim) const;
   
+  template<typename comparator>
+  inline arma_warn_unused bool is_sorted_helper(const comparator& comp, const uword dim) const;
+  
   arma_inline arma_warn_unused bool in_range(const uword ii) const;
   arma_inline arma_warn_unused bool in_range(const span& x ) const;
   
@@ -475,8 +478,8 @@ class Mat : public Base< eT, Mat<eT> >
   inline const Mat& eye(const uword in_rows, const uword in_cols);
   inline const Mat& eye(const SizeMat& s);
   
-  inline void      reset();
-  inline void soft_reset();
+  inline arma_cold void      reset();
+  inline arma_cold void soft_reset();
   
   
   template<typename T1> inline void set_real(const Base<pod_type,T1>& X);
