@@ -29,6 +29,16 @@ SpBase<elem_type,derived>::get_ref() const
 
 
 
+template<typename elem_type, typename derived>
+arma_inline
+bool
+SpBase<elem_type,derived>::is_alias(const SpMat<elem_type>& X) const
+  {
+  return (*this).get_ref().is_alias(X);
+  }
+
+
+
 template<typename elem_type, typename derived>
 inline
 const SpOp<derived, spop_htrans>
@@ -328,4 +338,37 @@ SpBase<elem_type,derived>::index_max() const
 
 
 
+template<typename elem_type, typename derived>
+inline
+arma_warn_unused
+bool
+SpBase<elem_type,derived>::is_finite() const
+  {
+  arma_extra_debug_sigprint();
+  
+  const SpProxy<derived> P( (*this).get_ref() );
+  
+  if(is_SpMat<typename SpProxy<derived>::stored_type>::value)
+    {
+    const unwrap_spmat<typename SpProxy<derived>::stored_type> U(P.Q);
+    
+    return U.M.is_finite();
+    }
+  else
+    {
+    typename SpProxy<derived>::const_iterator_type it     = P.begin();
+    typename SpProxy<derived>::const_iterator_type it_end = P.end();
+    
+    while(it != it_end)
+      {
+      if(arma_isfinite(*it) == false)  { return false; }
+      ++it;
+      }
+    }
+  
+  return true;
+  }
+
+
+
 //! @}
