@@ -96,6 +96,16 @@ class auxlib
   inline static bool eig_gen(Mat< std::complex<typename T1::pod_type> >& vals, Mat< std::complex<typename T1::pod_type> >& vecs, const bool vecs_on, const Base< std::complex<typename T1::pod_type>, T1 >& expr);
   
   
+  //
+  // eig_gen_balance
+  
+  template<typename T1>
+  inline static bool eig_gen_balance(Mat< std::complex<typename T1::pod_type> >& vals, Mat< std::complex<typename T1::pod_type> >& vecs, const bool vecs_on, const Base<typename T1::pod_type,T1>& expr);
+  
+  template<typename T1>
+  inline static bool eig_gen_balance(Mat< std::complex<typename T1::pod_type> >& vals, Mat< std::complex<typename T1::pod_type> >& vecs, const bool vecs_on, const Base< std::complex<typename T1::pod_type>, T1 >& expr);
+  
+  
   //
   // eig_pair
   
@@ -131,6 +141,9 @@ class auxlib
   //
   // chol
   
+  template<typename eT>
+  inline static bool chol_simple(Mat<eT>& X);
+  
   template<typename eT>
   inline static bool chol(Mat<eT>& X, const uword layout);
   
