@@ -1,12 +1,17 @@
-// Copyright (C) 2009-2016 National ICT Australia (NICTA)
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
-// Written by Dimitrios Bouzas
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 
@@ -215,7 +220,7 @@ op_shuffle_default::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_shuff
   
   const unwrap<T1> U(in.m);
   
-  const uword dim = (T1::is_row) ? 1 : 0;
+  const uword dim = (T1::is_row) ? 1 : 0;  // NOTE: this only checks the type; U.M.n_rows == 1 is not checked
   
   op_shuffle::apply_direct(out, U.M, dim);
   }
