@@ -1,11 +1,17 @@
-// Copyright (C) 2008-2015 National ICT Australia (NICTA)
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup op_sort
@@ -22,13 +28,13 @@ op_sort::direct_sort(eT* X, const uword n_elem, const uword sort_type)
   
   if(sort_type == 0)
     {
-    arma_ascend_sort_helper<eT> comparator;
+    arma_lt_comparator<eT> comparator;
     
     std::sort(&X[0], &X[n_elem], comparator);
     }
   else
     {
-    arma_descend_sort_helper<eT> comparator;
+    arma_gt_comparator<eT> comparator;
     
     std::sort(&X[0], &X[n_elem], comparator);
     }
@@ -43,7 +49,7 @@ op_sort::direct_sort_ascending(eT* X, const uword n_elem)
   {
   arma_extra_debug_sigprint();
   
-  arma_ascend_sort_helper<eT> comparator;
+  arma_lt_comparator<eT> comparator;
     
   std::sort(&X[0], &X[n_elem], comparator);
   }
