@@ -286,10 +286,53 @@ operator*
 
 
 
+//! non-complex sparse * complex scalar
+template<typename T1>
+arma_inline
+typename
+enable_if2
+  <
+  (is_arma_sparse_type<T1>::value && is_cx<typename T1::elem_type>::no),
+  const mtSpOp<typename std::complex<typename T1::pod_type>, T1, spop_cx_scalar_times>
+  >::result
+operator*
+  (
+  const T1&                                  X,
+  const std::complex<typename T1::pod_type>& k
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  return mtSpOp<typename std::complex<typename T1::pod_type>, T1, spop_cx_scalar_times>('j', X, k);
+  }
+
+
+
+//! complex scalar * non-complex sparse
+template<typename T1>
+arma_inline
+typename
+enable_if2
+  <
+  (is_arma_sparse_type<T1>::value && is_cx<typename T1::elem_type>::no),
+  const mtSpOp<typename std::complex<typename T1::pod_type>, T1, spop_cx_scalar_times>
+  >::result
+operator*
+  (
+  const std::complex<typename T1::pod_type>& k,
+  const T1&                                  X
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  return mtSpOp<typename std::complex<typename T1::pod_type>, T1, spop_cx_scalar_times>('j', X, k);
+  }
+
+
+
 //! multiplication of two sparse objects
 template<typename T1, typename T2>
 inline
-arma_hot
 typename
 enable_if2
   <
@@ -309,152 +352,6 @@ operator*
 
 
 
-//! convert "(sparse + sparse) * scalar" to specialised operation "scalar * (sparse + sparse)"
-template<typename T1, typename T2>
-inline
-const SpGlue<T1,T2,spglue_plus2>
-operator*
-  (
-  const SpGlue<T1,T2,spglue_plus>& X,
-  const typename T1::elem_type k
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return SpGlue<T1,T2,spglue_plus2>(X.A, X.B, k);
-  }
-
-
-
-//! convert "scalar * (sparse + sparse)" to specialised operation 
-template<typename T1, typename T2>
-inline
-const SpGlue<T1,T2,spglue_plus2>
-operator*
-  (
-  const typename T1::elem_type k,
-  const SpGlue<T1,T2,spglue_plus>& X
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return SpGlue<T1,T2,spglue_plus2>(X.A, X.B, k);
-  }
-
-
-
-//! convert "(sparse - sparse) * scalar" to specialised operation "scalar * (sparse - sparse)"
-template<typename T1, typename T2>
-inline
-const SpGlue<T1,T2,spglue_minus2>
-operator*
-  (
-  const SpGlue<T1,T2,spglue_minus>& X,
-  const typename T1::elem_type k
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return SpGlue<T1,T2,spglue_minus2>(X.A, X.B, k);
-  }
-
-
-
-//! convert "scalar * (sparse - sparse)" to specialised operation 
-template<typename T1, typename T2>
-inline
-const SpGlue<T1,T2,spglue_minus2>
-operator*
-  (
-  const typename T1::elem_type k,
-  const SpGlue<T1,T2,spglue_minus>& X
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return SpGlue<T1,T2,spglue_minus2>(X.A, X.B, k);
-  }
-
-
-
-//! convert "(sparse*sparse) * scalar" to specialised operation "scalar * (sparse*sparse)"
-template<typename T1, typename T2>
-inline
-const SpGlue<T1,T2,spglue_times2>
-operator*
-  (
-  const SpGlue<T1,T2,spglue_times>& X,
-  const typename T1::elem_type k
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return SpGlue<T1,T2,spglue_times2>(X.A, X.B, k);
-  }
-
-
-
-//! convert "scalar * (sparse*sparse)" to specialised operation
-template<typename T1, typename T2>
-inline
-const SpGlue<T1,T2,spglue_times2>
-operator*
-  (
-  const typename T1::elem_type k,
-  const SpGlue<T1,T2,spglue_times>& X
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return SpGlue<T1,T2,spglue_times2>(X.A, X.B, k);
-  }
-
-
-
-//! convert "(scalar*sparse) * sparse" to specialised operation "scalar * (sparse*sparse)"
-template<typename T1, typename T2>
-inline
-typename
-enable_if2
-  <
-  is_arma_sparse_type<T2>::value,
-  const SpGlue<T1,T2,spglue_times2>
-  >::result
-operator*
-  (
-  const SpOp<T1,spop_scalar_times>& X,
-  const T2& Y
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return SpGlue<T1,T2,spglue_times2>(X.m, Y, X.aux);
-  }
-
-
-
-//! convert "sparse * (scalar*sparse)" to specialised operation "scalar * (sparse*sparse)"
-template<typename T1, typename T2>
-inline
-typename
-enable_if2
-  <
-  is_arma_sparse_type<T1>::value,
-  const SpGlue<T1,T2,spglue_times2>
-  >::result
-operator*
-  (
-  const T1& X,
-  const SpOp<T2,spop_scalar_times>& Y
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  return SpGlue<T1,T2,spglue_times2>(X, Y.m, Y.aux);
-  }
-
-
-
 //! multiplication of one sparse and one dense object
 template<typename T1, typename T2>
 inline
@@ -511,4 +408,82 @@ operator*
 
 
 
+//! multiplication of two sparse objects with different element types
+template<typename T1, typename T2>
+inline
+typename
+enable_if2
+  <
+  (is_arma_sparse_type<T1>::value && is_arma_sparse_type<T2>::value && (is_same_type<typename T1::elem_type, typename T2::elem_type>::no)),
+  SpMat< typename promote_type<typename T1::elem_type, typename T2::elem_type>::result >
+  >::result
+operator*
+  (
+  const T1& X,
+  const T2& Y
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  SpMat< typename promote_type<typename T1::elem_type, typename T2::elem_type>::result > out;
+  
+  spglue_times_mixed::sparse_times_sparse(out, X, Y);
+  
+  return out;
+  }
+
+
+
+//! multiplication of one sparse and one dense object with different element types
+template<typename T1, typename T2>
+inline
+typename
+enable_if2
+  <
+  (is_arma_sparse_type<T1>::value && is_arma_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::no),
+  Mat< typename promote_type<typename T1::elem_type, typename T2::elem_type>::result >
+  >::result
+operator*
+  (
+  const T1& X,
+  const T2& Y
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat< typename promote_type<typename T1::elem_type, typename T2::elem_type>::result > out;
+  
+  spglue_times_mixed::sparse_times_dense(out, X, Y);
+  
+  return out;
+  }
+
+
+
+//! multiplication of one dense and one sparse object with different element types
+template<typename T1, typename T2>
+inline
+typename
+enable_if2
+  <
+  (is_arma_type<T1>::value && is_arma_sparse_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::no),
+  Mat< typename promote_type<typename T1::elem_type, typename T2::elem_type>::result >
+  >::result
+operator*
+  (
+  const T1& X,
+  const T2& Y
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat< typename promote_type<typename T1::elem_type, typename T2::elem_type>::result > out;
+  
+  spglue_times_mixed::dense_times_sparse(out, X, Y);
+  
+  return out;
+  }
+
+
+
 //! @}
